==> mahara-1.9.1.txz: usr/local/www/mahara/artefact/plans/lang/en.utf8/artefact.plans.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

/* Plans */
$string['pluginname'] = 'Plans';

$string['canteditdontownplan'] = 'You cannot edit this plan because you do not own it.';
$string['description'] = 'Description';
$string['deleteplanconfirm'] = 'Are you sure you wish to delete this plan? Deleting this plan will also remove any tasks it contains.';
$string['deleteplan'] = 'Delete plan';
$string['deletethisplan'] = 'Delete plan: \'%s\'';
$string['editplan'] = 'Edit plan';
$string['editingplan'] = 'Editing plan';
$string['managetasks'] = 'Manage tasks';
$string['managetasksspecific'] = 'Manage tasks in "%s"';
$string['newplan'] = 'New plan';
$string['noplansaddone'] = 'No plans yet. %sAdd one%s!';
$string['noplans'] = 'No plans to display';
$string['plan'] = 'Plan';
$string['plans'] = 'Plans';
$string['Plans'] = 'Plans';
$string['plandeletedsuccessfully'] = 'Plan deleted successfully.';
$string['plannotdeletedsuccessfully'] = 'There was an error deleting this plan.';
$string['plannotsavedsuccessfully'] = 'There was an error submitting this form. Please check the marked fields and try again.';
$string['plansavedsuccessfully'] = 'Plan saved successfully.';
$string['planstasks'] = 'Plan \'%s\' tasks.';
$string['planstasksdescription'] = 'Add tasks below or use the "%s" button to begin building your plan.';
$string['saveplan'] = 'Save plan';
$string['title'] = 'Title';
$string['titledesc'] = 'The title will be used to display each task in the plans blocktype.';

/* Tasks */
$string['alltasks'] = 'All tasks';
$string['canteditdontowntask'] = 'You cannot edit this task because you do not own it.';
$string['completed'] = 'Completed';
$string['incomplete'] = 'Incomplete';
$string['overdue'] = 'Overdue';
$string['completiondate'] = 'Completion date';
$string['completeddesc'] = 'Mark your task completed.';
$string['deletetaskconfirm'] = 'Are you sure you wish to delete this task?';
$string['deletetask'] = 'Delete task';
$string['deletethistask'] = 'Delete task: \'%s\'';
$string['edittask'] = 'Edit task';
$string['editingtask'] = 'Editing task';
$string['mytasks'] = 'My tasks';
$string['newtask'] = 'New task';
$string['notasks'] = 'No tasks to display.';
$string['notasksaddone'] = 'No tasks yet. %sAdd one%s.';
$string['savetask'] = 'Save task';
$string['task'] = 'task';
$string['Task'] = 'Task';
$string['tasks'] = 'tasks';
$string['Tasks'] = 'Tasks';
$string['taskdeletedsuccessfully'] = 'Task deleted successfully.';
$string['tasksavedsuccessfully'] = 'Task saved successfully.';
$string['ntasks'] = array(
        '1 task',
        '%s tasks',
);
$string['duplicatedplan'] = 'Duplicated plan';
$string['existingplans'] = 'Existing plans';
$string['duplicatedtask'] = 'Duplicated task';
$string['existingtasks'] = 'Existing tasks';

$string['progress_plan'] = array(
    'Add a plan',
    'Add %s plans',
);
$string['progress_task'] = array(
    'Add a task to a plan',
    'Add %s tasks to a plan',
);

==> mahara-15.04.0_1.txz: usr/local/www/mahara/artefact/plans/lang/en.utf8/artefact.plans.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

/* Plans */
$string['pluginname'] = 'Plans';

$string['canteditdontownplan'] = 'You cannot edit this plan because you do not own it.';
$string['description'] = 'Description';
$string['deleteplanconfirm'] = 'Are you sure you wish to delete this plan? Deleting this plan will also remove any tasks it contains.';
$string['deleteplan'] = 'Delete plan';
$string['deletethisplan'] = 'Delete plan: \'%s\'';
$string['editplan'] = 'Edit plan';
$string['editingplan'] = 'Editing plan';
$string['managetasks'] = 'Manage tasks';
$string['managetasksspecific'] = 'Manage tasks in "%s"';
$string['newplan'] = 'New plan';
$string['noplansaddone'] = 'No plans yet. %sAdd one%s!';
$string['noplans'] = 'No plans to display';
$string['plan'] = 'Plan';
$string['plans'] = 'Plans';
$string['Plans'] = 'Plans';
$string['plandeletedsuccessfully'] = 'Plan deleted successfully.';
$string['plannotdeletedsuccessfully'] = 'There was an error deleting this plan.';
$string['plannotsavedsuccessfully'] = 'There was an error submitting this form. Please check the marked fields and try again.';
$string['plansavedsuccessfully'] = 'Plan saved successfully.';
$string['planstasks'] = 'Plan \'%s\' tasks';
$string['planstasksdescription'] = 'Add tasks below or use the "%s" button to begin building your plan.';
$string['saveplan'] = 'Save plan';
$string['title'] = 'Title';
$string['titledesc'] = 'The title will be used to display each task in the plans blocktype.';

/* Tasks */
$string['alltasks'] = 'All tasks';
$string['canteditdontowntask'] = 'You cannot edit this task because you do not own it.';
$string['completed'] = 'Completed';
$string['incomplete'] = 'Incomplete';
$string['overdue'] = 'Overdue';
$string['completiondate'] = 'Completion date';
$string['completeddesc'] = 'Mark your task completed.';
$string['deletetaskconfirm'] = 'Are you sure you wish to delete this task?';
$string['deletetask'] = 'Delete task';
$string['deletethistask'] = 'Delete task: \'%s\'';
$string['edittask'] = 'Edit task';
$string['editingtask'] = 'Editing task';
$string['mytasks'] = 'My tasks';
$string['newtask'] = 'New task';
$string['notasks'] = 'No tasks to display.';
$string['notasksaddone'] = 'No tasks yet. %sAdd one%s.';
$string['savetask'] = 'Save task';
$string['task'] = 'task';
$string['Task'] = 'Task';
$string['tasks'] = 'tasks';
$string['Tasks'] = 'Tasks';
$string['taskdeletedsuccessfully'] = 'Task deleted successfully.';
$string['tasksavedsuccessfully'] = 'Task saved successfully.';
$string['ntasks'] = array(
        '1 task',
        '%s tasks',
);
$string['duplicatedplan'] = 'Duplicated plan';
$string['existingplans'] = 'Existing plans';
$string['duplicatedtask'] = 'Duplicated task';
$string['existingtasks'] = 'Existing tasks';

$string['progress_plan'] = array(
    'Add a plan',
    'Add %s plans',
);
$string['progress_task'] = array(
    'Add a task to a plan',
    'Add %s tasks to a plan',
);
